==> portal-service-6.0.6-sources.jar: com/liferay/portal/kernel/util/ContentTypes.java <==
/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.kernel.util;

/**
 * @author Brian Wing Shun Chan
 */
public interface ContentTypes {

	public static final String APPLICATION_ATOM_XML = "application/atom+xml";

	public static final String APPLICATION_MSWORD = "application/msword";

	public static final String APPLICATION_OCTET_STREAM =
		"application/octet-stream";

	public static final String APPLICATION_TEXT = "application/text";

	public static final String APPLICATION_X_WWW_FORM_URLENCODED =
		"application/x-www-form-urlencoded";

	public static final String APPLICATION_ZIP = "application/zip";

	public static final String HTTPD_UNIX_DIRECTORY = "httpd/unix-directory";

	public static final String IMAGE_JPEG = "image/jpeg";

	public static final String MESSAGE_RFC822 = "message/rfc822";

	public static final String MULTIPART_ALTERNATIVE = "multipart/alternative";

	public static final String MULTIPART_FORM_DATA = "multipart/form-data";

	public static final String MULTIPART_MIXED = "multipart/mixed";

	public static final String TEXT_CALENDAR = "text/calendar";

	public static final String TEXT_CSS = "text/css";

	public static final String TEXT_CSS_UTF8 = "text/css; charset=UTF-8";

	public static final String TEXT_CSV = "text/csv";

	public static final String TEXT_CSV_UTF8 = "text/csv; charset=UTF-8";

	public static final String TEXT_HTML = "text/html";

	public static final String TEXT_HTML_UTF8 = "text/html; charset=UTF-8";

	public static final String TEXT_JAVASCRIPT = "text/javascript";

	public static final String TEXT_PLAIN = "text/plain";

	public static final String TEXT_PLAIN_UTF8 = "text/plain; charset=UTF-8";

	public static final String TEXT_WML = "text/wml";

	public static final String TEXT_XML = "text/xml";

	public static final String TEXT_XML_UTF8 = "text/xml; charset=UTF-8";

	public static final String XHTML_MP = "application/vnd.wap.xhtml+xml";

}

==> portal-service-6.1.0-sources.jar: com/liferay/portal/kernel/util/ContentTypes.java <==
/**
 * Copyright (c) 2000-2012 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.kernel.util;

/**
 * @author Brian Wing Shun Chan
 */
public interface ContentTypes {

	public static final String APPLICATION_ATOM_XML = "application/atom+xml";

	public static final String APPLICATION_JSON = "application/json";

	public static final String APPLICATION_MSWORD = "application/msword";

	public static final String APPLICATION_OCTET_STREAM =
		"application/octet-stream";

	public static final String APPLICATION_PDF = "application/pdf";

	public static final String APPLICATION_TEXT = "application/text";

	public static final String APPLICATION_VND_MS_EXCEL =
		"application/vnd.ms-excel";

	public static final String APPLICATION_VND_MS_POWERPOINT =
		"application/vnd.ms-powerpoint";

	public static final String APPLICATION_X_JAVA_SERIALIZED_OBJECT =
		"application/x-java-serialized-object";

	public static final String APPLICATION_X_PDF = "application/x-pdf";

	public static final String APPLICATION_X_WWW_FORM_URLENCODED =
		"application/x-www-form-urlencoded";

	public static final String APPLICATION_X_WWW_FORM_URLENCODED_UTF8 =
		"application/x-www-form-urlencoded; charset=UTF-8";

	public static final String APPLICATION_ZIP = "application/zip";

	public static final String HTTPD_UNIX_DIRECTORY = "httpd/unix-directory";

	public static final String IMAGE_JPEG = "image/jpeg";

	public static final String MESSAGE_RFC822 = "message/rfc822";

	public static final String MULTIPART_ALTERNATIVE = "multipart/alternative";

	public static final String MULTIPART_FORM_DATA = "multipart/form-data";

	public static final String MULTIPART_MIXED = "multipart/mixed";

	public static final String TEXT = "text";

	public static final String TEXT_CALENDAR = "text/calendar";

	public static final String TEXT_CSS = "text/css";

	public static final String TEXT_CSS_UTF8 = "text/css; charset=UTF-8";

	public static final String TEXT_CSV = "text/csv";

	public static final String TEXT_CSV_UTF8 = "text/csv; charset=UTF-8";

	public static final String TEXT_HTML = "text/html";

	public static final String TEXT_HTML_UTF8 = "text/html; charset=UTF-8";

	public static final String TEXT_JAVASCRIPT = "text/javascript";

	public static final String TEXT_PLAIN = "text/plain";

	public static final String TEXT_PLAIN_UTF8 = "text/plain; charset=UTF-8";

	public static final String TEXT_WML = "text/wml";

	public static final String TEXT_XML = "text/xml";

	public static final String TEXT_XML_UTF8 = "text/xml; charset=UTF-8";

	public static final String XHTML_MP = "application/vnd.wap.xhtml+xml";

}
